import fs from 'node:fs'
import path from 'node:path'
import { fileURLToPath, URL } from 'node:url'
import { resolve } from 'node:path'

import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'
import AutoImport from 'unplugin-auto-import/vite'
import Components from 'unplugin-vue-components/vite'
import { ArcoResolver } from 'unplugin-vue-components/resolvers'
import cssInjectedByJsPlugin from 'vite-plugin-css-injected-by-js'

// https://vitejs.dev/config/
export default defineConfig({
  define: {
    'process.env': process.env
  },
  plugins: [
    vue(),
    AutoImport({ imports: ['vue'], eslintrc: { enabled: true }, resolvers: [ArcoResolver()] }),
    Components({
      resolvers: [
        ArcoResolver({
          resolveIcons: true,
          sideEffect: true
        })
      ]
    }),
    cssInjectedByJsPlugin()
  ],
  resolve: {
    alias: {
      '@': fileURLToPath(new URL('./src', import.meta.url))
    }
  },
  server: {
    open: true,
    host: 'dev.ezijing.com',
    https: {
      key: fs.readFileSync(path.join(import.meta.dirname, './https/ezijing.com.key')),
      cert: fs.readFileSync(path.join(import.meta.dirname, './https/ezijing.com.pem'))
    },
    proxy: {
      '/api': 'https://saas-lab.ezijing.com'
    }
  },
  build: {
    lib: {
      entry: resolve(import.meta.dirname, 'src/main.js'),
      name: 'SkyAgent',
      fileName: 'sky-agent'
    }
  }
})
